@@ -3,7 +3,6 @@ from typing import List, Union, Optional
 
 from dask.dataframe import DataFrame
 from dask import dataframe as dd, delayed
-from distributed import Client
 from fsspec.core import OpenFile, open_files
 from pandas import DataFrame as PDataFrame
 from pyexcelerate import Workbook
@@ -128,8 +127,7 @@ class ValidFormatJob:
             output_path = output_path + label + "/"
 
         if output_format == "csv":
-            dd.to_csv(df, output_path)
-            df.to_csv(output_path, index=False)
+            dd.to_csv(df, output_path, index=False)
             final = good_job()
         elif output_format == "parquet":
             dd.to_parquet(df, output_path)
