@@ -8,7 +8,7 @@ from mason_dask.utils.worker_spec import WorkerSpec
 class ClusterSpec:
     
     def __init__(self, client: Client):
-        self.worker_specs: Optional[List[WorkerSpec]] = None
+        self.worker_specs: List[WorkerSpec] = []
         if client.cluster and client.cluster.scheduler:
             workers_dict: dict = client.cluster.scheduler.workers
             workers: List[WorkerState] = list({k: workers_dict[k] for k in workers_dict.keys() if isinstance(workers_dict[k], WorkerState)}.values())
@@ -19,6 +19,6 @@ class ClusterSpec:
         return min(list(map(lambda s: s.memory, self.worker_specs)))
     
     def num_workers(self) -> Optional[int]:
-        if self.worker_specs:
+        if len(self.worker_specs) > 0:
             return len(self.worker_specs)
     
